summaryrefslogtreecommitdiffstats
path: root/chrome/browser/history
diff options
context:
space:
mode:
authorsky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-11 15:22:32 +0000
committersky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-11 15:22:32 +0000
commitd8e41ed4a55e60be60d47de5bbcb8a027e85a879 (patch)
treee0feaa030fe3834c0fc871de7564ef74e9595b05 /chrome/browser/history
parent7903e0262e2dda44eaa186d126cf88e2cc1470eb (diff)
downloadchromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.zip
chromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.tar.gz
chromium_src-d8e41ed4a55e60be60d47de5bbcb8a027e85a879.tar.bz2
Renames BoomarkBarModel to BookmarkModel.
BUG=none TEST=none Review URL: http://codereview.chromium.org/1912 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@2057 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/history')
-rw-r--r--chrome/browser/history/expire_history_backend_unittest.cc4
-rw-r--r--chrome/browser/history/history_backend_unittest.cc8
-rw-r--r--chrome/browser/history/starred_url_database.cc16
3 files changed, 14 insertions, 14 deletions
diff --git a/chrome/browser/history/expire_history_backend_unittest.cc b/chrome/browser/history/expire_history_backend_unittest.cc
index daaf43b..e067894 100644
--- a/chrome/browser/history/expire_history_backend_unittest.cc
+++ b/chrome/browser/history/expire_history_backend_unittest.cc
@@ -7,7 +7,7 @@
#include "base/file_util.h"
#include "base/path_service.h"
#include "base/scoped_ptr.h"
-#include "chrome/browser/bookmarks/bookmark_bar_model.h"
+#include "chrome/browser/bookmarks/bookmark_model.h"
#include "chrome/browser/history/archived_database.h"
#include "chrome/browser/history/expire_history_backend.h"
#include "chrome/browser/history/history_database.h"
@@ -65,7 +65,7 @@ class ExpireHistoryTest : public testing::Test,
static bool IsStringInFile(std::wstring& filename, const char* str);
- BookmarkBarModel bookmark_model_;
+ BookmarkModel bookmark_model_;
MessageLoop message_loop_;
diff --git a/chrome/browser/history/starred_url_database.cc b/chrome/browser/history/starred_url_database.cc
index 6b61f31..67baced 100644
--- a/chrome/browser/history/starred_url_database.cc
+++ b/chrome/browser/history/starred_url_database.cc
@@ -7,8 +7,8 @@
#include "base/file_util.h"
#include "base/logging.h"
#include "base/json_writer.h"
-#include "chrome/browser/bookmarks/bookmark_bar_model.h"
#include "chrome/browser/bookmarks/bookmark_codec.h"
+#include "chrome/browser/bookmarks/bookmark_model.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/query_parser.h"
#include "chrome/browser/meta_table_helper.h"
@@ -541,14 +541,14 @@ bool StarredURLDatabase::MigrateBookmarksToFileImpl(const std::wstring& path) {
// Create the bookmark bar and other folder nodes.
history::StarredEntry entry;
entry.type = history::StarredEntry::BOOKMARK_BAR;
- BookmarkBarNode bookmark_bar_node(NULL, GURL());
+ BookmarkNode bookmark_bar_node(NULL, GURL());
bookmark_bar_node.Reset(entry);
entry.type = history::StarredEntry::OTHER;
- BookmarkBarNode other_node(NULL, GURL());
+ BookmarkNode other_node(NULL, GURL());
other_node.Reset(entry);
std::map<history::UIStarID, history::StarID> group_id_to_id_map;
- typedef std::map<history::StarID, BookmarkBarNode*> IDToNodeMap;
+ typedef std::map<history::StarID, BookmarkNode*> IDToNodeMap;
IDToNodeMap id_to_node_map;
history::UIStarID other_folder_group_id = 0;
@@ -586,14 +586,14 @@ bool StarredURLDatabase::MigrateBookmarksToFileImpl(const std::wstring& path) {
continue;
}
- BookmarkBarNode* node = id_to_node_map[i->id];
+ BookmarkNode* node = id_to_node_map[i->id];
if (!node) {
// Creating a node results in creating the parent. As such, it is
// possible for the node representing a group to have been created before
// encountering the details.
// The created nodes are owned by the root node.
- node = new BookmarkBarNode(NULL, i->url);
+ node = new BookmarkNode(NULL, i->url);
id_to_node_map[i->id] = node;
}
node->Reset(*i);
@@ -601,10 +601,10 @@ bool StarredURLDatabase::MigrateBookmarksToFileImpl(const std::wstring& path) {
DCHECK(group_id_to_id_map.find(i->parent_group_id) !=
group_id_to_id_map.end());
history::StarID parent_id = group_id_to_id_map[i->parent_group_id];
- BookmarkBarNode* parent = id_to_node_map[parent_id];
+ BookmarkNode* parent = id_to_node_map[parent_id];
if (!parent) {
// Haven't encountered the parent yet, create it now.
- parent = new BookmarkBarNode(NULL, GURL());
+ parent = new BookmarkNode(NULL, GURL());
id_to_node_map[parent_id] = parent;
}
diff --git a/chrome/browser/history/history_backend_unittest.cc b/chrome/browser/history/history_backend_unittest.cc
index 5f91019..3bbb716 100644
--- a/chrome/browser/history/history_backend_unittest.cc
+++ b/chrome/browser/history/history_backend_unittest.cc
@@ -5,7 +5,7 @@
#include "base/file_util.h"
#include "base/path_service.h"
#include "base/scoped_ptr.h"
-#include "chrome/browser/bookmarks/bookmark_bar_model.h"
+#include "chrome/browser/bookmarks/bookmark_model.h"
#include "chrome/browser/history/history_backend.h"
#include "chrome/browser/history/in_memory_history_backend.h"
#include "chrome/browser/history/in_memory_database.h"
@@ -69,7 +69,7 @@ class HistoryBackendTest : public testing::Test {
backend_->AddPage(request);
}
- BookmarkBarModel bookmark_model_;
+ BookmarkModel bookmark_model_;
protected:
bool loaded_;
@@ -315,7 +315,7 @@ TEST_F(HistoryBackendTest, URLsNoLongerBookmarked) {
// Unstar row2.
bookmark_model_.SetURLStarred(row2.url(), std::wstring(), false);
// Tell the backend it was unstarred. We have to explicitly do this as
// BookmarkBarModel isn't wired up to the backend during testing.
std::set<GURL> unstarred_urls;
unstarred_urls.insert(row2.url());
backend_->URLsNoLongerBookmarked(unstarred_urls);
@@ -329,7 +329,7 @@ TEST_F(HistoryBackendTest, URLsNoLongerBookmarked) {
// Unstar row 1.
bookmark_model_.SetURLStarred(row1.url(), std::wstring(), false);
// Tell the backend it was unstarred. We have to explicitly do this as
// BookmarkBarModel isn't wired up to the backend during testing.
unstarred_urls.clear();
unstarred_urls.insert(row1.url());
backend_->URLsNoLongerBookmarked(unstarred_urls);
@@ -315,7 +315,7 @@ TEST_F(HistoryBackendTest, URLsNoLongerBookmarked) {
bookmark_model_.SetURLStarred(row2.url(), std::wstring(), false);
// Tell the backend it was unstarred. We have to explicitly do this as
- // BookmarkBarModel isn't wired up to the backend during testing.
+ // BookmarkModel isn't wired up to the backend during testing.
std::set<GURL> unstarred_urls;
unstarred_urls.insert(row2.url());
@@ -329,7 +329,7 @@ TEST_F(HistoryBackendTest, URLsNoLongerBookmarked) {
bookmark_model_.SetURLStarred(row1.url(), std::wstring(), false);
// Tell the backend it was unstarred. We have to explicitly do this as
- // BookmarkBarModel isn't wired up to the backend during testing.
+ // BookmarkModel isn't wired up to the backend during testing.
unstarred_urls.clear();
unstarred_urls.insert(row1.url());